@@ -37,9 +37,9 @@
 
 #include <kmime/kmime_message.h>
 
-#include <mailtransport/dispatchmodeattribute.h>
-#include <mailtransport/sentbehaviourattribute.h>
-#include <mailtransport/transportattribute.h>
+#include <mailtransportakonadi/dispatchmodeattribute.h>
+#include <mailtransportakonadi/sentbehaviourattribute.h>
+#include <mailtransportakonadi/transportattribute.h>
 
 using namespace Akonadi;
 using namespace MailTransport;
@@ -56,8 +56,8 @@ public:
     Private(OutboxQueue *qq)
         : q(qq),
           outbox(-1),
-          monitor(Q_NULLPTR),
-          futureTimer(Q_NULLPTR),
+          monitor(nullptr),
+          futureTimer(nullptr),
           totalSize(0),
           outboxDiscoveryRetries(0)
     {
@@ -163,7 +163,7 @@ void OutboxQueue::Private::addIfComplete(const Item &item)
 
     const TransportAttribute *transportAttribute = item.attribute<TransportAttribute>();
     Q_ASSERT(transportAttribute);
-    if (transportAttribute->transport() == Q_NULLPTR) {
+    if (transportAttribute->transport() == nullptr) {
         qCWarning(MAILDISPATCHER_LOG) << "Item" << item.id() << "has invalid transport.";
         return;
     }
@@ -251,7 +251,8 @@ void OutboxQueue::Private::collectionFetched(KJob *job)
     Q_ASSERT(fetchJob);
     qCDebug(MAILDISPATCHER_LOG) << "Fetched" << fetchJob->items().count() << "items.";
 
-    foreach (const Item &item, fetchJob->items()) {
+    const Akonadi::Item::List lst = fetchJob->items();
+    for (const Item &item : lst ) {
         addIfComplete(item);
     }
 }
@@ -331,7 +332,7 @@ void OutboxQueue::Private::localFoldersRequestResult(KJob *job)
             qCWarning(MAILDISPATCHER_LOG) << "Failed to get outbox folder. Retrying in: " << timeout;
             QTimer::singleShot(timeout, q, SLOT(localFoldersChanged()));
         } else {
-            qCWarning(MAILDISPATCHER_LOG) << "Failed to get outbox folder. Giving up.";;
+            qCWarning(MAILDISPATCHER_LOG) << "Failed to get outbox folder. Giving up.";
             Q_EMIT q->error(i18n("Could not access the outbox folder (%1).", job->errorString()));
         }
         return;
