@@ -1,5 +1,5 @@
 /*
-    Copyright (c) 2013-2015 Laurent Montel <montel@kde.org>
+    Copyright (c) 2013-2017 Laurent Montel <montel@kde.org>
 
     This library is free software; you can redistribute it and/or modify it
     under the terms of the GNU Library General Public License as published by
@@ -31,7 +31,7 @@ class NewMailNotifierSettingsDialog : public QDialog
 {
     Q_OBJECT
 public:
-    explicit NewMailNotifierSettingsDialog(QWidget *parent = Q_NULLPTR);
+    explicit NewMailNotifierSettingsDialog(QWidget *parent = nullptr);
     ~NewMailNotifierSettingsDialog();
 
 private:
