@@ -21,11 +21,11 @@
 
 #include <KCalCore/FreeBusy>
 
-#include <QtCore/QMap>
-#include <QtCore/QObject>
-#include <QtCore/QString>
+#include <QMap>
+#include <QObject>
+#include <QString>
 
-class KDateTime;
+class QDateTime;
 class KJob;
 
 /**
@@ -55,7 +55,7 @@ public:
      * @param start The start of the free-busy period to report
      * @param end The end of the free-busy period to report
      */
-    void retrieveFreeBusy(const QString &email, const KDateTime &start, const KDateTime &end);
+    void retrieveFreeBusy(const QString &email, const QDateTime &start, const QDateTime &end);
 
 Q_SIGNALS:
     /**
