@@ -36,7 +36,7 @@ public:
 
     qint64 newUid() const;
 
-    void start() Q_DECL_OVERRIDE;
+    void start() override;
 
 private:
     void triggerSearchJob();
