@@ -158,7 +158,7 @@ private:
         parts.append(mLastModified);
 
         entity.setRemoteId(QString::number(mObjectId));
-        entity.setRemoteRevision(parts.join(QStringLiteral(":")));
+        entity.setRemoteRevision(parts.join(QLatin1Char(':')));
     }
 
     qlonglong mObjectId;
@@ -173,7 +173,7 @@ public:
     {
         if (!Settings::self()->objectsLastSync().isEmpty()) {
             const QStringList pairs = Settings::self()->objectsLastSync().split(QLatin1Char(':'), QString::KeepEmptyParts);
-            foreach (const QString &pair, pairs) {
+            for (const QString &pair : pairs) {
                 const QStringList entry = pair.split(QLatin1Char('='), QString::KeepEmptyParts);
                 mObjectsMap.insert(entry.at(0).toLongLong(), entry.at(1).toULongLong());
             }
@@ -191,17 +191,13 @@ public:
             pairs.append(QString::number(it.key()) + QLatin1Char('=') + QString::number(it.value()));
         }
 
-        Settings::self()->setObjectsLastSync(pairs.join(QStringLiteral(":")));
+        Settings::self()->setObjectsLastSync(pairs.join(QLatin1Char(':')));
         Settings::self()->save();
     }
 
     qulonglong lastSync(qlonglong collectionId) const
     {
-        if (!mObjectsMap.contains(collectionId)) {
-            return 0;
-        }
-
-        return mObjectsMap.value(collectionId);
+        return mObjectsMap.value(collectionId, 0);
     }
 
     void setLastSync(qlonglong collectionId, qulonglong timeStamp)
@@ -663,7 +659,7 @@ void OpenXchangeResource::onObjectsRequestJobFinished(KJob *job)
     Item::List items;
 
     const OXA::Object::List objects = requestJob->objects();
-    foreach (const OXA::Object &object, objects) {
+    for (const OXA::Object &object : objects) {
         Item item;
         switch (object.module()) {
         case OXA::Folder::Contacts:
@@ -715,7 +711,7 @@ void OpenXchangeResource::onObjectsRequestDeltaJobFinished(KJob *job)
     Item::List changedItems;
 
     const OXA::Object::List modifiedObjects = requestJob->modifiedObjects();
-    foreach (const OXA::Object &object, modifiedObjects) {
+    for (const OXA::Object &object : modifiedObjects) {
         Item item;
         switch (object.module()) {
         case OXA::Folder::Contacts:
@@ -753,7 +749,7 @@ void OpenXchangeResource::onObjectsRequestDeltaJobFinished(KJob *job)
 
     const OXA::Object::List deletedObjects = requestJob->deletedObjects();
     removedItems.reserve(deletedObjects.count());
-    foreach (const OXA::Object &object, deletedObjects) {
+    for (const OXA::Object &object : deletedObjects) {
         Item item;
 
         const RemoteInformation remoteInformation(object.objectId(), object.module(), object.lastModified());
@@ -1026,9 +1022,9 @@ void OpenXchangeResource::onFoldersRequestDeltaJobFinished(KJob *job)
     Collection::List removedCollections;
 
     // add the deleted folders from the server
-    OXA::Folder::List deletedFolders = requestJob->deletedFolders();
+    const OXA::Folder::List deletedFolders = requestJob->deletedFolders();
     removedCollections.reserve(deletedFolders.count());
-    foreach (const OXA::Folder &folder, deletedFolders) {
+    for (const OXA::Folder &folder : deletedFolders) {
         Collection collection;
         collection.setRemoteId(QString::number(folder.objectId()));
 
@@ -1169,7 +1165,7 @@ void OpenXchangeResource::onFetchResourceCollectionsFinished(KJob *job)
 
     // copy the remaining collections of the resource
     const Collection::List collections = fetchJob->collections();
-    foreach (const Collection &collection, collections) {
+    for (const Collection &collection : collections) {
         mCollectionsMap.insert(collection.remoteId().toULongLong(), collection);
     }
 }
