@@ -34,7 +34,7 @@ public:
 FileStore::CollectionMoveJob::CollectionMoveJob(const Collection &collection, const Collection &targetParent, FileStore::AbstractJobSession *session)
     : FileStore::Job(session), d(new Private())
 {
-    Q_ASSERT(session != 0);
+    Q_ASSERT(session != nullptr);
 
     d->mCollection = collection;
     d->mTargetParent = targetParent;
